- https://askubuntu.com/questions/90764/how-do-i-create-a-deb-package-for-a-single-python-script

# Browser Support Tests

| Exp. Support | Support | Sender OS | Sender Browser | Receiver OS | Receiver Browser |
|--------------|---------|-----------|----------------|-------------|------------------|
|              | yes     | Windows   | Firefox        | Linux       | Firefox          |
| no           | no      | Windows   | Chrome         | Linux       | Firefox          |
|              | yes     | Windows   | Firefox        | Linux       | Chrome           |
| yes          | no      | Windows   | Chrome         | Linux       | Chrome           |
|              |         |           |                |             |                  |
|              | yes     | Linux     | Firefox        | Windows     | Firefox          |
| yes          | no      | Linux     | Chrome         | Windows     | Firefox          |
| yes          | no      | Linux     | Firefox        | Windows     | Chrome           |
| yes          | no      | Linux     | Chrome         | Windows     | Chrome           |
|              |         |           |                |             |                  |
| yes          | no      | Linux     | Chrome         | Linux       | Chrome           |
| yes          | no      | Linux     | Firefox        | Linux       | Chrome           |
|              | yes     | Linux     | Firefox        | Linux       | Firefox          |
|              | yes     | Linux     | Chrome         | Linux       | Firefox          |
